IGNITE-14127: Default sql page size from 1 => 1024

This closes #13
diff --git a/pyignite/client.py b/pyignite/client.py
index f8072d8..83cb196 100644
--- a/pyignite/client.py
+++ b/pyignite/client.py
@@ -519,7 +519,7 @@
         return cache_get_names(self.random_node)
 
     def sql(
-        self, query_str: str, page_size: int = 1, query_args: Iterable = None,
+        self, query_str: str, page_size: int = 1024, query_args: Iterable = None,
         schema: Union[int, str] = 'PUBLIC',
         statement_type: int = 0, distributed_joins: bool = False,
         local: bool = False, replicated_only: bool = False,
@@ -531,8 +531,8 @@
         Runs an SQL query and returns its result.
 
         :param query_str: SQL query string,
         :param page_size: (optional) cursor page size. Default is 1, which
          means that client makes one server call per row,
         :param query_args: (optional) query arguments. List of values or
          (value, type hint) tuples,
         :param schema: (optional) schema for the query. Defaults to `PUBLIC`,
@@ -531,8 +531,8 @@
 
         :param query_str: SQL query string,
-        :param page_size: (optional) cursor page size. Default is 1, which
-         means that client makes one server call per row,
+        :param page_size: (optional) cursor page size. Default is 1024, which
+         means that client makes one server call per 1024 rows,
         :param query_args: (optional) query arguments. List of values or
          (value, type hint) tuples,